@@ -35,7 +35,12 @@ from .namespace import Namespace, star
 from .loaders import add_loader, drop_loader
 from .errors import ConfigError
 
-__version__ = '0.8.0'
+try:
+    from . import voluptuous
+except ImportError:
+    pass
+
+__version__ = '0.11.0'
 
 for obj in [parametrize, fixture, Namespace, star, ConfigError, add_loader, drop_loader, load_parameters]:
     obj.__module__ = 'parametrize_from_file'
